@@ -1,4 +1,4 @@
-/* Copyright (C) 2009, 2010, 2011 Keith Crane
+/* Copyright (C) 2009, 2010, 2011, 2012 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -30,6 +30,7 @@ typedef struct proc_s	proc_t;
 struct proc_s {
 	pid_t	pid;
 	char	**exec_args;
+	char	**env_var;
 	int	status;
 	int	signal_value;
 	int	stdout_fd;
@@ -49,17 +50,19 @@ typedef struct {
 	unsigned short	max_processes;
 	char	**exec_arg;
 	unsigned short	exec_arg_cnt;
+	char	**env_var;
+	unsigned short	env_var_cnt;
 	unsigned char	successful_exit[UCHAR_MAX+1];
 } step_t;
 
-int get_args( int, char * const [], const char **, unsigned short *, unsigned short *, const char **, const char **, const char **, const char **, const char ** );
+int get_args( int, char * const [], const char **, const char ** );
 int parse_exec_args( const char *, char *** );
 proc_t *alloc_proc_tbl( unsigned short );
 int assign_fname( char **, const char *, unsigned short, unsigned short, const char * );
 
-int start_procs( unsigned short *, unsigned short *, proc_t *, void **proc_tree, char **, unsigned short, unsigned short, int, unsigned short, step_t *, int, const char * );
+int start_procs( unsigned short *, proc_t *, void **proc_tree, char **, unsigned short, unsigned short, unsigned short, step_t *, int, const char * );
 
-pid_t exec_proc( int *, int *, char * const *, const char *, const char *, const char * );
+pid_t exec_proc( int *, int *, char * const *, char **, const char *, const char *, const char * );
 int proc_cmp( const void *, const void * );
 int wait_proc( unsigned short *, void **, int *, proc_t **, int, const char *, const char * );
 int replace_arg_flags( char **, unsigned short, const char * );
@@ -67,7 +70,7 @@ int assign_input_fname( const char ***, unsigned short *, const char * );
 int get_divvy_text( char ***, unsigned short *, const char * );
 int load_recovery_log( proc_t *, unsigned short *, unsigned short, unsigned short, const char * );
 int write_recovery_log( proc_t *, unsigned short, unsigned short, const char * );
-int assign_exec_args( char ***, char **, unsigned short, const char *, unsigned short );
+int assign_exec_args( char ***, char ***, char **, unsigned short, char **, unsigned short, const char *, unsigned short );
 int set_proc_list( proc_t **, unsigned short *, proc_t *, completed_t *, unsigned long, char **, unsigned short, const char *, const unsigned char * );
 int get_cpu_semid( const char * );
 int request_proc_resource( int *, unsigned short, int );
@@ -85,7 +88,7 @@ int assign_string( char **, sexpr_t *, const char *, unsigned short );
 void print_job( const char *, step_t *, unsigned short );
 
 int copy_exec_args( char ***, char **, unsigned short );
-int process_step( step_t *, completed_t *, unsigned long, int, int, const char * );
+int process_step( step_t *, completed_t *, unsigned long, int, const char * );
 int open_log_file( const char * );
 int write_log_record( int, const char *, const char *, const char *, pid_t, const char, int *, int * );
 void control_syntax_error( const char *, const char *, int, unsigned short );
@@ -94,5 +97,6 @@ int assign_exit_values( unsigned char *, sexpr_t *, unsigned short );
 int load_completed( completed_t **, unsigned long *, const char *, const char * );
 int completed_cmp( const void *, const void * );
 int completed_status( int *, int *, completed_t *, unsigned long, const char *, const char *, const unsigned char * );
+int assign_setenv( char ***, unsigned short *, sexpr_t *, unsigned short );
 
 #define CONTROL_SYNTAX_ERROR( m, t )    control_syntax_error( m, __FILE__, __LINE__, t )
