@@ -1,4 +1,4 @@
-/* Copyright (C) 2009, 2010, 2011 Keith Crane
+/* Copyright (C) 2009, 2010, 2011, 2012 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -39,7 +39,7 @@ int get_divvy_text( char ***divvy_text, unsigned short *divvy_text_cnt, const ch
 {
 	unsigned long	divvy_int;
 	size_t	len;
-	char	*int_ptr;
+	char	*int_ptr, *file_path;
 
 	assert( divvy_text != (char ***)0 );
 	assert( divvy_text_cnt != (unsigned short *)0 );
@@ -50,10 +50,15 @@ int get_divvy_text( char ***divvy_text, unsigned short *divvy_text_cnt, const ch
 	*divvy_text_cnt = (unsigned short)0;
 	*divvy_text = (char **)0;
 
-	if ( isdigit( *divvy_fname ) ) {
-		len = strlen( divvy_fname );
-		divvy_int = strtoul( divvy_fname, &int_ptr, 10 );
-		if ( int_ptr == &divvy_fname[ len ] && divvy_int > 0L && divvy_int < (unsigned long)USHRT_MAX ) {
+	file_path = strenv( divvy_fname );
+	if ( file_path == (char *)0 ) {
+		RETURN_INT( -1 );
+	}
+
+	if ( isdigit( *file_path ) ) {
+		len = strlen( file_path );
+		divvy_int = strtoul( file_path, &int_ptr, 10 );
+		if ( int_ptr == &file_path[ len ] && divvy_int > 0L && divvy_int < (unsigned long)USHRT_MAX ) {
 			if ( construct_divvy( divvy_text, divvy_text_cnt, (unsigned short)divvy_int ) == -1 ) {
 				RETURN_INT( -1 );
 			}
@@ -62,22 +67,16 @@ int get_divvy_text( char ***divvy_text, unsigned short *divvy_text_cnt, const ch
 		}
 	}
 
-	if ( load_file( divvy_text, divvy_text_cnt, divvy_fname ) == -1 ) {
+	if ( load_file( divvy_text, divvy_text_cnt, file_path ) == -1 ) {
 		RETURN_INT( -1 );
 	}
 
 	RETURN_INT( 0 );
 }
 
-static int load_file( char ***divvy_text, unsigned short *divvy_text_cnt, const char *divvy_fname )
+static int load_file( char ***divvy_text, unsigned short *divvy_text_cnt, const char *file_path )
 {
 	unsigned long	divvy_text_cnt_tmp;
-	char	*file_path;
-
-	file_path = strenv( divvy_fname );
-	if ( file_path == (char *)0 ) {
-		return -1;
-	}
 
 	divvy_text_cnt_tmp = 0UL;
 
