@@ -1,4 +1,4 @@
-/* Copyright (C) 2009, 2010, 2011 Keith Crane
+/* Copyright (C) 2009, 2010, 2011, 2012 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -32,11 +32,9 @@ with DFILE Tools; see the file COPYING.  If not, see
 */
 int main( int argc, char **argv )
 {
-	unsigned short	max_concurrent_jobs, retries;
-	const char	*command, *output_name;
-	const char	*divvy_fname, *job_name;
-	const char	*recovery_log, *cpu_semid_fname, *control_fname;
-	int	cpu_semid, log_fd;
+	const char	*job_name;
+	const char	*recovery_log, *control_fname;
+	int	log_fd;
 	step_t	*step;
 	unsigned short	step_cnt;
 	time_t	prev_utime = 0, prev_stime = 0, prev_rtime, gmt;
@@ -49,7 +47,7 @@ int main( int argc, char **argv )
 	/*
 	** Process command line arguments.
 	*/
-	if ( get_args( argc, argv, &divvy_fname, &max_concurrent_jobs, &retries, &command, &output_name, &recovery_log, &cpu_semid_fname, &control_fname ) == -1 ) {
+	if ( get_args( argc, argv, &recovery_log, &control_fname ) == -1 ) {
 		return 10;
 	}
 
@@ -66,8 +64,6 @@ Debug = 1;
 		RETURN_INT( 25 );
 	}
 
-	cpu_semid = get_cpu_semid( cpu_semid_fname );
-
 	log_fd = open_log_file( recovery_log );
 	if ( log_fd < 0 ) {
 		RETURN_INT( 30 );
@@ -76,7 +72,7 @@ Debug = 1;
 	(void) time( &prev_rtime );
 
 	for ( ; step_cnt > (unsigned short)0; --step_cnt ) {
-		if ( process_step( step, completed, completed_cnt, cpu_semid, log_fd, job_name ) == -1 ) {
+		if ( process_step( step, completed, completed_cnt, log_fd, job_name ) == -1 ) {
 			RETURN_INT( 35 );
 		}
 		if ( getrusage( RUSAGE_CHILDREN, &r_usage ) == -1 ) {
