@@ -1,4 +1,4 @@
-/* Copyright (C) 2009, 2010, 2011 Keith Crane
+/* Copyright (C) 2009, 2010, 2011, 2012 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -37,8 +37,8 @@ int _dfile_bind( dfile_bind_t **cfg_bind, unsigned short cfg_bind_cnt, const dfi
 {
 	static const char	bind_err_msg1[] = "Failed to match program bind variable [";
 	static const char	bind_err_msg2[] = "] with record layout.\n";
-	int	bind_error_flag, cmp;
-	dfile_bind_t	*ptr;
+	int	bind_error_flag;
+	dfile_bind_t	**search_result;
 
 	assert( cfg_bind != (dfile_bind_t **)0 );
 	assert( cfg_bind_cnt > (unsigned short)0 );
@@ -50,17 +50,10 @@ int _dfile_bind( dfile_bind_t **cfg_bind, unsigned short cfg_bind_cnt, const dfi
 	*/
 	bind_error_flag = 0;
 
-	while ( cfg_bind_cnt > (unsigned short)0 && pgm_var_cnt > (unsigned short)0 ) {
-		ptr = *cfg_bind;
+	for ( ; pgm_var_cnt > (unsigned short)0; ++pgm_var, --pgm_var_cnt ) {
+		search_result = (dfile_bind_t **)bsearch( (void *)&pgm_var, cfg_bind, cfg_bind_cnt, sizeof( dfile_bind_t * ), dfile_bind_field_name_cmp );
 
-		cmp = strcasecmp( pgm_var->field_name, ptr->field_name );
-		if ( cmp > 0 ) {
-			++cfg_bind;
-			--cfg_bind_cnt;
-			continue;
-		}
-
-		if ( cmp < 0 ) {
+		if ( search_result == (dfile_bind_t **)0 ) {
 			/*
 			** Set bind_error_flag to true.
 			*/
@@ -70,9 +63,6 @@ int _dfile_bind( dfile_bind_t **cfg_bind, unsigned short cfg_bind_cnt, const dfi
 			(void) fputs( bind_err_msg1, stderr );
 			(void) fputs( pgm_var->field_name, stderr );
 			(void) fputs( bind_err_msg2, stderr );
-
-			++pgm_var;
-			--pgm_var_cnt;
 			continue;
 		}
 
@@ -80,27 +70,10 @@ int _dfile_bind( dfile_bind_t **cfg_bind, unsigned short cfg_bind_cnt, const dfi
 			(void) fprintf( stderr, "[%s], %p %p\n", pgm_var->field_name, pgm_var->field_buffer, pgm_var->field_length );
 		}
 
-		ptr->field_buffer = pgm_var->field_buffer;
-		ptr->field_length = pgm_var->field_length;
-
-		++pgm_var;
-		--pgm_var_cnt;
-
-		++cfg_bind;
-		--cfg_bind_cnt;
+		( *search_result )->field_buffer = pgm_var->field_buffer;
+		( *search_result )->field_length = pgm_var->field_length;
 	}
 
-	while ( pgm_var_cnt > (unsigned short)0 ) {
-		FPUT_SRC_CODE( stderr );
-		(void) fputs( bind_err_msg1, stderr );
-		(void) fputs( pgm_var->field_name, stderr );
-		(void) fputs( bind_err_msg2, stderr );
-
-		++pgm_var;
-		--pgm_var_cnt;
-	}
-
-
 	if ( bind_error_flag ) {
 		RETURN_INT( -1 );
 	}
