@@ -1,4 +1,4 @@
-/* Copyright (C) 2009, 2010, 2011 Keith Crane
+/* Copyright (C) 2009, 2010, 2011, 2012 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -21,6 +21,8 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <string.h>
 #include <assert.h>
 #include <limits.h>
+#undef DEBUG
+#define NDEBUG
 #include "tbox.h"
 
 /*
